==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/systemtags/l10n/eu.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistemak gehitutako%1$s sistemako etiketa",
    "Added system tag {systemtag}" : "{systemtag} sistemako etiketa gehituta",
    "Added system tag %1$s" : "%1$s sistemako etiketa gehitu da",
    "%1$s added system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa gehitu du",
    "{actor} added system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "System tag %1$s removed by the system" : "Sistemak kendutako %1$ssistemako etiketa",
    "Removed system tag {systemtag}" : "{systemtag} sistema etiketa kendu da",
    "Removed system tag %1$s" : "%1$s sistemako etiketa kendu da",
    "%1$s removed system tag %2$s" : "%1$s(e)k %2$s sistemaren etiketa kendu du",
    "{actor} removed system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du",
    "You created system tag %1$s" : "%1$s sistemako etiketa zuk sortu duzu",
    "You created system tag {systemtag}" : "{systemtag} sistemako etiketa zuk sortu duzu",
    "%1$s created system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa sortu du",
    "{actor} created system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "You deleted system tag %1$s" : "%1$s sistemako etiketa ezabatu duzu",
    "You deleted system tag {systemtag}" : "{systemtag} sistemako etiketa ezabatu duzu",
    "%1$s deleted system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa ezabatu du",
    "{actor} deleted system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa ezabatu du",
    "You updated system tag %2$s to %1$s" : "%2$s sistemako etiketa %1$s(e)ra eguneratu duzu",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistemako etiketa {newsystemtag}(e)ra eguneratu duzu",
    "%1$s updated system tag %3$s to %2$s" : "%1$s(e)k %3$s sistemako etiketa %2$s(e)ra eguneratu du",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}-(e)k  {oldsystemtag} sistemako etiketa eguneratu du {newsystemtag}-(e)ra",
    "System tag %2$s was added to %1$s by the system" : "Sistemak gehitu du %2$ssistemako etiketa %1$s-(e)ra ",
    "System tag {systemtag} was added to {file} by the system" : "Sistemak gehitu du {systemtag} sistemako etiketa {file}-(e)ra",
    "You added system tag %2$s to %1$s" : "%2$s sistemako etiketa gehitu duzu %1$s(e)ra",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistemako etiketa gehitu duzu {file}(e)ra",
    "%1$s added system tag %3$s to %2$s" : "%1$s-(e)k gehitu du %3$ssistemako etiketa %2$s-(e)ra",
    "{actor} added system tag {systemtag} to {file}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du {file}(e)ra",
    "System tag %2$s was removed from %1$s by the system" : "Sistemak kendu du %2$ssistemako etiketa %1$s-(e)tik",
    "System tag {systemtag} was removed from {file} by the system" : "Sistemak kendu du {systemtag} sistemako etiketa {file}-(e)tik",
    "You removed system tag %2$s from %1$s" : "%2$s sistemako etiketa %1$s(e)tik kendu duzu",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistemako etiketa ezabatu duzu {file} fitxategitik",
    "%1$s removed system tag %3$s from %2$s" : "%1$s-(e)k kendu du %3$ssistemako etiketa %2$s-(e)tik",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du {file}(e)tik",
    "%s (restricted)" : "%s (mugatua)",
    "%s (invisible)" : "%s (ikusezina)",
    "<strong>System tags</strong> for a file have been modified" : "Fitxategi baten <strong>sistema-etiketak</strong> aldatu egin dira",
    "Files" : "Fitxategiak",
    "Tags" : "Etiketak",
    "All tagged %s …" : "%sguztiak etiketatuta …",
    "tagged %s" : "%setiketatuta",
    "Collaborative tags" : "Elkarlaneko etiketak",
    "Collaborative tagging functionality which shares tags among people." : "Etiketak pertsonen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Etiketak pertsonen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea. Bikaina lantaldeentzat.\n\t(Maizter anitzeko instalazioa duen hornitzailea bazara, gomendatzen da aplikazio hau desaktibatzea etiketak partekatzen dira eta.)",
    "Public" : "Publikoa",
    "Restricted" : "Mugatua",
    "Invisible" : "Ikusezina",
    "Created tag" : "Etiketa sortu da",
    "Failed to create tag" : "Etiketa sortzeak huts egin du",
    "Updated tag" : "Etiketa eguneratu da",
    "Failed to update tag" : "Etiketa eguneratzeak huts egin du",
    "Deleted tag" : "Etiketa ezabatu da",
    "Failed to delete tag" : "Etiketa ezabatzeak huts egin du",
    "Create or edit tags" : "Sortu edo editatu etiketak",
    "Search for a tag to edit" : "Bilatu editatzeko etiketa",
    "Collaborative tags …" : "Elkarlaneko etiketak ...",
    "No tags to select" : "Ez da etiketarik hautatu",
    "Tag name" : "Etiketaren izena",
    "Tag level" : "Etiketaren maila",
    "Create" : "Sortu",
    "Update" : "Eguneratu",
    "Delete" : "Ezabatu",
    "Reset" : "Berrezarri",
    "Loading …" : "Kargatzen ...",
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} ezarriko zaio fitxategi bati.","{tag} ezarriko zaie {count} fitxategiri."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} kenduko zaio fitxategi bati.","{tag} kenduko zaie {count} fitxategiri."],
    "{displayName} (hidden)" : "{displayName} (ezkutua)",
    "{displayName} (restricted)" : "{displayName} (mugatua)",
    "Only admins can create new tags" : "Soilik administratzaileek sor ditzakete etiketa berriak",
    "Failed to apply tags changes" : "Etiketen aldaketak aplikatzeak huts egin du",
    "Manage tags" : "Kudeatu etiketak",
    "Applying tags changes…" : "Etiketen aldaketak aplikatzen...",
    "Search or create tag" : "Bilatu edo sortu etiketa",
    "Search tag" : "Bilatu etiketa",
    "Change tag color" : "Aldatu etiketaren kolorea",
    "Create new tag" : "Sortu etiketa berria",
    "Choose tags for the selected files" : "Aukeratu etiketak hautatutako fitxategientzat",
    "Cancel" : "Utzi",
    "Apply" : "Aplikatu",
    "Failed to load tags" : "Etiketak kargatzeak huts egin du",
    "Failed to load selected tags" : "Hautatutako etiketa kargatzeak huts egin du",
    "Failed to select tag" : "Etiketa hautatzeak huts egin du",
    "System admin disabled tag creation. You can only use existing ones." : "Sistemaren administratzaileak desgaitu du etiketen sortzea. Daudenak bakarrik erabili ditzakezu.",
    "Loading collaborative tags …" : "Elkarlaneko etiketak kargatzen ...",
    "Search or create collaborative tags" : "Bilatu edo sortu elkarlaneko etiketak",
    "No tags to select, type to create a new tag" : "Ez dago hautatzeko etiketarik, idatzi etiketa berria sortzeko",
    "System tag creation is now allowed for everybody" : "Orain edonork sor ditzake etiketak",
    "System tag management" : "Sistemaren etiketen kudeaketa",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Aktiboa badago, bakarrik administratzaileek sortu eta editatu ditzakete etiketak. Kontuek soilik esleitu edo kentzen ahal diete fitxategiei.",
    "Restrict tag creation and editing to administrators" : "Soilik administratzaileek sortu edo esleitu ditzakete etiketak",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Lankidetzazko etiketak erabilgarri daude erabiltzaile guztientzat. Erabiltzaileek  etiketa murriztuak ikusgai dituzte baina ezin dituzte haiek esleitu. Etiketa ikusezinak barne erabilerarako dira, erabiltzaileek ezin baitituzte ikusi edo esleitu.",
    "Assigned collaborative tags" : "Elkarlaneko etiketak esleituta",
    "Open in Files" : "Ireki Fitxategiak aplikazioan",
    "List of tags and their associated files and folders." : "Etiketak eta atxikituta dituzten fitxategi eta karpetak.",
    "No tags found" : "Ez da etiketarik aurkitu",
    "Tags you have created will show up here." : "Sortu dituzun etiketak hemen agertuko dira.",
    "Failed to load tag" : "Etiketa kargatzeak huts egin du",
    "Failed to load last used tags" : "Ezin izan dira azken erabilitako etiketak kargatu",
    "Missing \"Content-Location\" header" : "\"Content-Location\" goiburua falta",
    "A tag with the same name already exists" : "Izen bereko etiketa bat dagoeneko existitzen da",
    "Failed to load tags for file" : "Fitxategiarentzako etiketak kargatzeak huts egin du",
    "Failed to set tag for file" : "Fitxategiarentzako etiketa ezartzeak huts egin du",
    "Failed to delete tag for file" : "Fitxategiaren etiketa ezabatzeak huts egin du",
    "File tags modification canceled" : "Fitxategien etiketen aldaketa baztertuta",
    "Select or create tags to apply to all selected files" : "Hautatu edo sortu hautatutako fitxategi guztientzako etiketak",
    "Select tags to apply to all selected files" : "Hautatu zeintzuk etiketak esleitu hautatutako fitxategiei",
    "Apply changes" : "Aplikatu aldaketak"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.13.tar.bz2: nextcloud/apps/systemtags/l10n/eu.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistemak gehitutako%1$s sistemako etiketa",
    "Added system tag {systemtag}" : "{systemtag} sistemako etiketa gehituta",
    "Added system tag %1$s" : "%1$s sistemako etiketa gehitu da",
    "%1$s added system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa gehitu du",
    "{actor} added system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "System tag %1$s removed by the system" : "Sistemak kendutako %1$ssistemako etiketa",
    "Removed system tag {systemtag}" : "{systemtag} sistema etiketa kendu da",
    "Removed system tag %1$s" : "%1$s sistemako etiketa kendu da",
    "%1$s removed system tag %2$s" : "%1$s(e)k %2$s sistemaren etiketa kendu du",
    "{actor} removed system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du",
    "You created system tag %1$s" : "%1$s sistemako etiketa zuk sortu duzu",
    "You created system tag {systemtag}" : "{systemtag} sistemako etiketa zuk sortu duzu",
    "%1$s created system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa sortu du",
    "{actor} created system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du",
    "You deleted system tag %1$s" : "%1$s sistemako etiketa ezabatu duzu",
    "You deleted system tag {systemtag}" : "{systemtag} sistemako etiketa ezabatu duzu",
    "%1$s deleted system tag %2$s" : "%1$s(e)k %2$s sistemako etiketa ezabatu du",
    "{actor} deleted system tag {systemtag}" : "{actor}(e)k {systemtag} sistemako etiketa ezabatu du",
    "You updated system tag %2$s to %1$s" : "%2$s sistemako etiketa %1$s(e)ra eguneratu duzu",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistemako etiketa {newsystemtag}(e)ra eguneratu duzu",
    "%1$s updated system tag %3$s to %2$s" : "%1$s(e)k %3$s sistemako etiketa %2$s(e)ra eguneratu du",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}-(e)k  {oldsystemtag} sistemako etiketa eguneratu du {newsystemtag}-(e)ra",
    "System tag %2$s was added to %1$s by the system" : "Sistemak gehitu du %2$ssistemako etiketa %1$s-(e)ra ",
    "System tag {systemtag} was added to {file} by the system" : "Sistemak gehitu du {systemtag} sistemako etiketa {file}-(e)ra",
    "You added system tag %2$s to %1$s" : "%2$s sistemako etiketa gehitu duzu %1$s(e)ra",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistemako etiketa gehitu duzu {file}(e)ra",
    "%1$s added system tag %3$s to %2$s" : "%1$s-(e)k gehitu du %3$ssistemako etiketa %2$s-(e)ra",
    "{actor} added system tag {systemtag} to {file}" : "{actor}(e)k {systemtag} sistemako etiketa gehitu du {file}(e)ra",
    "System tag %2$s was removed from %1$s by the system" : "Sistemak kendu du %2$ssistemako etiketa %1$s-(e)tik",
    "System tag {systemtag} was removed from {file} by the system" : "Sistemak kendu du {systemtag} sistemako etiketa {file}-(e)tik",
    "You removed system tag %2$s from %1$s" : "%2$s sistemako etiketa %1$s(e)tik kendu duzu",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistemako etiketa ezabatu duzu {file} fitxategitik",
    "%1$s removed system tag %3$s from %2$s" : "%1$s-(e)k kendu du %3$ssistemako etiketa %2$s-(e)tik",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}(e)k {systemtag} sistemako etiketa kendu du {file}(e)tik",
    "%s (restricted)" : "%s (mugatua)",
    "%s (invisible)" : "%s (ikusezina)",
    "<strong>System tags</strong> for a file have been modified" : "Fitxategi baten <strong>sistema-etiketak</strong> aldatu egin dira",
    "Files" : "Fitxategiak",
    "Tags" : "Etiketak",
    "All tagged %s …" : "%sguztiak etiketatuta …",
    "tagged %s" : "%setiketatuta",
    "Collaborative tags" : "Elkarlaneko etiketak",
    "Collaborative tagging functionality which shares tags among people." : "Etiketak pertsonen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Etiketak pertsonen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea. Bikaina lantaldeentzat.\n\t(Maizter anitzeko instalazioa duen hornitzailea bazara, gomendatzen da aplikazio hau desaktibatzea etiketak partekatzen dira eta.)",
    "Public" : "Publikoa",
    "Restricted" : "Mugatua",
    "Invisible" : "Ikusezina",
    "Created tag" : "Etiketa sortu da",
    "Failed to create tag" : "Etiketa sortzeak huts egin du",
    "Updated tag" : "Etiketa eguneratu da",
    "Failed to update tag" : "Etiketa eguneratzeak huts egin du",
    "Deleted tag" : "Etiketa ezabatu da",
    "Failed to delete tag" : "Etiketa ezabatzeak huts egin du",
    "Create or edit tags" : "Sortu edo editatu etiketak",
    "Search for a tag to edit" : "Bilatu editatzeko etiketa",
    "Collaborative tags …" : "Elkarlaneko etiketak …",
    "No tags to select" : "Ez da etiketarik hautatu",
    "Tag name" : "Etiketaren izena",
    "Tag level" : "Etiketaren maila",
    "Create" : "Sortu",
    "Update" : "Eguneratu",
    "Delete" : "Ezabatu",
    "Reset" : "Berrezarri",
    "Loading …" : "Kargatzen …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} ezarriko zaio eta {tag2} kenduko zaio fitxategi bati.","{tag1} ezarriko zaie eta {tag2} kenduko zaie {count} fitxategitik."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} ezarriko zaio fitxategi bati.","{tag} ezarriko zaie {count} fitxategiri."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} kenduko zaio fitxategi bati.","{tag} kenduko zaie {count} fitxategiri."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} eta {lastTag} ezarriko zaizkio fitxategi bati.","{tags} eta {lastTag} ezarriko zaizkie {count} fitxategiri."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} eta {lastTag} kenduko zaizkio fitxategi bati..","{tags} eta {lastTag} zenduko zaizkie {count} fitxategiri."],
    "{displayName} (hidden)" : "{displayName} (ezkutua)",
    "{displayName} (restricted)" : "{displayName} (mugatua)",
    "Only admins can create new tags" : "Soilik administratzaileek sor ditzakete etiketa berriak",
    "Failed to apply tags changes" : "Etiketen aldaketak aplikatzeak huts egin du",
    "Manage tags" : "Kudeatu etiketak",
    "Applying tags changes…" : "Etiketen aldaketak aplikatzen...",
    "Search or create tag" : "Bilatu edo sortu etiketa",
    "Search tag" : "Bilatu etiketa",
    "Change tag color" : "Aldatu etiketaren kolorea",
    "Create new tag" : "Sortu etiketa berria",
    "Choose tags for the selected files" : "Aukeratu etiketak hautatutako fitxategientzat",
    "Cancel" : "Utzi",
    "Apply" : "Aplikatu",
    "Failed to load selected tags" : "Hautatutako etiketa kargatzeak huts egin du",
    "Failed to load tags" : "Etiketak kargatzeak huts egin du",
    "Failed to select tag" : "Etiketa hautatzeak huts egin du",
    "System admin disabled tag creation. You can only use existing ones." : "Sistemaren administratzaileak desgaitu du etiketen sortzea. Daudenak bakarrik erabili ditzakezu.",
    "Loading collaborative tags …" : "Elkarlaneko  etiketak kargatzen …",
    "Search or create collaborative tags" : "Bilatu edo sortu elkarlaneko etiketak",
    "No tags to select, type to create a new tag" : "Ez dago hautatzeko etiketarik, idatzi etiketa berria sortzeko",
    "Unable to update setting" : "Ezin izan dira ezarpenak eguneratu",
    "System tag creation is now restricted to administrators" : "Sistema-etiketen sortzea administratzaileei mugatuta dago orain",
    "System tag creation is now allowed for everybody" : "Orain edonork sor ditzake etiketak",
    "System tag management" : "Sistemaren etiketen kudeaketa",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Aktiboa badago, bakarrik administratzaileek sortu eta editatu ditzakete etiketak. Kontuek soilik esleitu edo kentzen ahal diete fitxategiei.",
    "Restrict tag creation and editing to administrators" : "Soilik administratzaileek sortu edo esleitu ditzakete etiketak",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Lankidetzazko etiketak erabilgarri daude erabiltzaile guztientzat. Erabiltzaileek  etiketa murriztuak ikusgai dituzte baina ezin dituzte haiek esleitu. Etiketa ikusezinak barne erabilerarako dira, erabiltzaileek ezin baitituzte ikusi edo esleitu.",
    "Add tags" : "Gehitu etiketak",
    "Assigned collaborative tags" : "Elkarlaneko etiketak esleituta",
    "Open in Files" : "Ireki Fitxategiak aplikazioan",
    "List of tags and their associated files and folders." : "Etiketak eta atxikituta dituzten fitxategi eta karpetak.",
    "No tags found" : "Ez da etiketarik aurkitu",
    "Tags you have created will show up here." : "Sortu dituzun etiketak hemen agertuko dira.",
    "Failed to load tag" : "Etiketa kargatzeak huts egin du",
    "Failed to load last used tags" : "Ezin izan dira azken erabilitako etiketak kargatu",
    "Missing \"Content-Location\" header" : "\"Content-Location\" goiburua falta",
    "A tag with the same name already exists" : "Izen bereko etiketa bat dagoeneko existitzen da",
    "Failed to load tags for file" : "Fitxategiarentzako etiketak kargatzeak huts egin du",
    "Failed to set tag for file" : "Fitxategiarentzako etiketa ezartzeak huts egin du",
    "Failed to delete tag for file" : "Fitxategiaren etiketa ezabatzeak huts egin du",
    "Collaborative tags …" : "Elkarlaneko etiketak ...",
    "Loading …" : "Kargatzen ...",
    "File tags modification canceled" : "Fitxategien etiketen aldaketa baztertuta",
    "Select or create tags to apply to all selected files" : "Hautatu edo sortu hautatutako fitxategi guztientzako etiketak",
    "Select tags to apply to all selected files" : "Hautatu zeintzuk etiketak esleitu hautatutako fitxategiei",
    "Apply changes" : "Aplikatu aldaketak",
    "Loading collaborative tags …" : "Elkarlaneko etiketak kargatzen ..."
},
"nplurals=2; plural=(n != 1);");
